@@ -43,27 +43,30 @@ static GNode *asn1_cert = NULL;
 static guchar *data_cert = NULL;
 static gsize n_data_cert = 0;
 
-DEFINE_SETUP(asn1_tree)
+TESTING_SETUP(asn1_tree)
 {
 	data_cert = testing_data_read ("test-certificate-1.der", &n_data_cert);
 
-	asn1_cert = egg_asn1x_create_and_decode (pkix_asn1_tab, "Certificate", data_cert, n_data_cert);
+	asn1_cert = egg_asn1x_create (pkix_asn1_tab, "Certificate");
 	g_assert (asn1_cert != NULL);
+
+	if (!egg_asn1x_decode (asn1_cert, data_cert, n_data_cert))
+		egg_asn1x_assert_not_reached (asn1_cert);
 }
 
-DEFINE_TEARDOWN(asn1_tree)
+TESTING_TEARDOWN(asn1_tree)
 {
 	egg_asn1x_destroy (asn1_cert);
 	g_free (data_cert);
 	data_cert = NULL;
 }
 
-DEFINE_TEST(node_name)
+TESTING_TEST(node_name)
 {
 	g_assert_cmpstr (egg_asn1x_name (asn1_cert), ==, "Certificate");
 }
 
-DEFINE_TEST(asn1_integers)
+TESTING_TEST(asn1_integers)
 {
 	GNode *asn;
 	guchar *data;
@@ -109,7 +112,7 @@ DEFINE_TEST(asn1_integers)
 	g_free (data);
 }
 
-DEFINE_TEST(boolean)
+TESTING_TEST(boolean)
 {
 	GNode *asn = NULL;
 	gboolean value, ret;
@@ -150,7 +153,7 @@ DEFINE_TEST(boolean)
 	egg_asn1x_destroy (asn);
 }
 
-DEFINE_TEST(write_value)
+TESTING_TEST(write_value)
 {
 	GNode *asn = NULL;
 	guchar *data;
@@ -177,7 +180,7 @@ DEFINE_TEST(write_value)
 	egg_asn1x_destroy (asn);
 }
 
-DEFINE_TEST(element_length_content)
+TESTING_TEST(element_length_content)
 {
 	GNode *asn = NULL;
 	gchar *buffer;
@@ -202,17 +205,25 @@ DEFINE_TEST(element_length_content)
 	content = egg_asn1x_element_content (buffer, length, &n_content);
 	g_assert (content);
 	g_assert_cmpuint (n_content, ==, 11);
-	
+
 	content = egg_asn1x_element_content (content, n_content, &n_content);
 	g_assert (content);
 	g_assert_cmpuint (n_content, ==, 9);	
 	g_assert (memcmp (content, "SOME DATA", 9) == 0);
 
+	const char *BAD_ASN_TAG = "\x00";
+	content = egg_asn1x_element_content (BAD_ASN_TAG, 1, &n_content);
+	g_assert (content == NULL);
+
+	const char *BAD_ASN_LENGTH = "\x30\x80";
+	content = egg_asn1x_element_content (BAD_ASN_LENGTH, 2, &n_content);
+	g_assert (content == NULL);
+
 	egg_asn1x_destroy (asn);
 	g_free (buffer);
 }
 
-DEFINE_TEST(read_element)
+TESTING_TEST(read_element)
 {
 	GNode *asn = NULL;
 	guchar *buffer;
@@ -243,7 +254,7 @@ DEFINE_TEST(read_element)
 	g_free (buffer);
 }
 
-DEFINE_TEST(oid)
+TESTING_TEST(oid)
 {
 	GNode *asn = NULL;
 	GQuark oid, check;
@@ -295,6 +306,10 @@ static const TimeTestData generalized_time_test_data[] = {
 	{ "20070725013528+1130", 1185368728 },
 	{ "20070725Z", 1185321600 },
 	{ "20070725+0000", 1185321600 },
+
+	/* Bad ones */
+	{ "200707", -1 },
+
 	{ NULL, 0 }
 };
 
@@ -312,11 +327,14 @@ static const TimeTestData utc_time_test_data[] = {
 	{ "070725013528+1130", 1185368728 },
 	{ "070725Z", 1185321600 },
 	{ "070725+0000", 1185321600 },
-	
+
+	/* Bad ones */
+	{ "0707", -1 },
+
 	{ NULL, 0 }
 };
 
-DEFINE_TEST(general_time)
+TESTING_TEST(general_time)
 {
 	time_t when;
 	const TimeTestData *data;
@@ -334,7 +352,7 @@ DEFINE_TEST(general_time)
 	}
 }
 
-DEFINE_TEST(utc_time)
+TESTING_TEST(utc_time)
 {
 	time_t when;
 	const TimeTestData *data;
@@ -352,7 +370,7 @@ DEFINE_TEST(utc_time)
 	}
 }
 
-DEFINE_TEST(read_time)
+TESTING_TEST(read_time)
 {
 	glong time;
 
@@ -360,7 +378,7 @@ DEFINE_TEST(read_time)
 	g_assert_cmpint (time, ==, 820454400);
 }
 
-DEFINE_TEST(read_date)
+TESTING_TEST(read_date)
 {
 	GDate date;
 	if (!egg_asn1x_get_time_as_date (egg_asn1x_node (asn1_cert, "tbsCertificate", "validity", "notAfter", NULL), &date))
@@ -370,7 +388,7 @@ DEFINE_TEST(read_date)
 	g_assert_cmpint (date.year, ==, 2020);
 }
 
-DEFINE_TEST(create_by_oid)
+TESTING_TEST(create_by_oid)
 {
 	/* id-at-initials = X520initials */
 	GNode *node = egg_asn1x_create (pkix_asn1_tab, "2.5.4.43");
@@ -379,13 +397,13 @@ DEFINE_TEST(create_by_oid)
 	egg_asn1x_destroy (node);
 }
 
-DEFINE_TEST(create_by_oid_invalid)
+TESTING_TEST(create_by_oid_invalid)
 {
 	GNode *node = egg_asn1x_create (pkix_asn1_tab, "23.23.23.23");
 	g_assert (node == NULL);
 }
 
-DEFINE_TEST(create_by_bad_order)
+TESTING_TEST(create_by_bad_order)
 {
 	/*
 	 * In pkix.asn the definition for parts of this oid
@@ -399,7 +417,7 @@ DEFINE_TEST(create_by_bad_order)
 	egg_asn1x_destroy (node);
 }
 
-DEFINE_TEST(count)
+TESTING_TEST(count)
 {
 	GNode *node;
 
