@@ -23,17 +23,18 @@
 
 #include "config.h"
 
-#include "run-auto-test.h"
+#include "test-suite.h"
 
+#include "egg/egg-error.h"
 #include "egg/egg-secure-memory.h"
 
-#include "gcr/gcr-parser.h"
+#include "gcr/gcr.h"
+#include "gcr/gcr-internal.h"
 
-#include "gp11/gp11.h"
+#include "gck/gck.h"
 
 #include <glib.h>
 #include <gcrypt.h>
-#include <libtasn1.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -58,7 +59,7 @@ static const gchar* filedesc = NULL;
 static void
 parsed_item (GcrParser *par, gpointer user_data)
 {
-	GP11Attributes *attrs;
+	GckAttributes *attrs;
 	const gchar *description;
 	const gchar *label;
 	
@@ -91,20 +92,23 @@ authenticate (GcrParser *par, gint state, gpointer user_data)
 	};
 } 
 
-DEFINE_SETUP(parser)
+TESTING_SETUP(parser)
 {
+	/* Look for the config in the build directory */
+	_gcr_set_pkcs11_config_dir (TEST_CONFIG_DIR);
+
 	parser = gcr_parser_new ();
 	g_signal_connect (parser, "parsed", G_CALLBACK (parsed_item), parser);
 	g_signal_connect (parser, "authenticate", G_CALLBACK (authenticate), parser);
 }
 
-DEFINE_TEARDOWN(parser)
+TESTING_TEARDOWN(parser)
 {
 	g_object_unref (parser);
 	parser = NULL;
 }
 
-DEFINE_TEST(parse_all)
+TESTING_TEST(parse_all)
 {
 	guchar *contents;
 	GError *err = NULL;
@@ -113,7 +117,7 @@ DEFINE_TEST(parse_all)
 	gsize len;
 	GDir *dir;
 	
-	dir = g_dir_open ("test-data", 0, NULL);
+	dir = g_dir_open (testing_data_directory (), 0, NULL);
 	g_assert (dir);
 
 	for (;;) {
@@ -124,12 +128,14 @@ DEFINE_TEST(parse_all)
 			continue;
 		
 		filedesc = filename;
-		contents = test_read_testdata (filename, &len);
+		contents = testing_data_read (filename, &len);
 		
 		result = gcr_parser_parse_data (parser, contents, len, &err);
+		g_free (contents);
+
 		if (!result) { 
 			g_warning ("couldn't parse file data: %s: %s", 
-			           filename, err && err->message ? err->message : "");
+			           filename, egg_error_message (err));
 			g_error_free (err);
 			g_assert (FALSE);
 		}
